<?php

namespace App\Http\Controllers\Api;

use App\Http\Controllers\Controller;
use App\Http\Requests\Api\RegisterRequest;
use App\Models\User;
use Illuminate\Http\JsonResponse;
use Illuminate\Http\Request;

class PassportAuthController extends Controller
{
    /**
     * @param RegisterRequest $request
     * @return JsonResponse
     */
    public function register(RegisterRequest $request): JsonResponse
    {
        $user = User::create([
            'name' => $request->name,
            'email' => $request->email,
            'password' => bcrypt($request->password)
        ]);

        return response()->json(
            ['token' => $user->createToken('LaravelAuthApp')->accessToken],
            201
        );
    }

    /**
     * @param Request $request
     * @return JsonResponse
     */
    public function login(Request $request): JsonResponse
    {
        if (auth()->attempt($request->only(['email', 'password']))) {
            return response()
                ->json(['token' => auth()->user()->createToken('LaravelAuthApp')->accessToken]);
        }

        return response()->json(['error' => 'Unauthorised'], 401);
    }
}
