import React, {useEffect, useState} from "react";
import {Container, Menu} from "semantic-ui-react";
import {Link, useLocation, useNavigate} from "react-router-dom";

const Navbar = () => {
    const [state, setState] = useState({
        isAuth: false,
        activeItem: 'home'
    });
    const location = useLocation();
    const navigate = useNavigate();

    useEffect(() => {
        const token = localStorage.getItem('token');

        if (token) {
            setState(prevState => ({...prevState, isAuth: true}));
        }
    }, [location]);

    const handleItemClick = (e, { name }) => setState(prevState => ({...prevState, activeItem: name }));

    const handleLogOut = (e) => {
        setState({ isAuth: false, activeItem: 'logout' });
        localStorage.removeItem('token');
        navigate("/login");
    };

    const authButtons = () => {
        return (
            <>
                <Menu.Item
                    as={Link} to="/login"
                    name='login'
                    active={state.activeItem === 'login'}
                    onClick={handleItemClick}
                />
                <Menu.Item
                    as={Link} to="/register"
                    name='register'
                    active={state.activeItem === 'register'}
                    onClick={handleItemClick}
                />
            </>
        );
    };

    const logOutButton = () => {
        return (
            <>
                <Menu.Item
                    name='logout'
                    active={state.activeItem === 'logout'}
                    onClick={handleLogOut}
                />
            </>
        )
    };

    return (
        <div>
            <Menu fixed="top" inverted>
                <Container>
                    <Menu.Item name='home' active={state.activeItem === 'home'} as={Link} to="/" header  onClick={handleItemClick}>
                        Home
                    </Menu.Item>
                    {
                        state.isAuth &&
                        <Menu.Item name='articles' active={state.activeItem === 'articles'}
                                   as={Link} to="/articles" onClick={handleItemClick}>
                            Articles
                        </Menu.Item>
                    }
                    <Menu.Menu position='right'>
                        {state.isAuth ? logOutButton() : authButtons()}
                    </Menu.Menu>
                </Container>
            </Menu>
        </div>
    );
};

export default Navbar;
