import React, {useEffect, useState} from "react";
import './ArticlesPage.css';
import {API_BASE_URL} from "../../config";
import {Header, Message} from "semantic-ui-react";
import ArticlesPageTable from "../../components/ArticlesPageTable/ArticlesPageTable";
import {useNavigate} from "react-router-dom";
import {get} from "../../services/request";

const ArticlesPage = () => {
    const [state, setState] = useState({
        articles: null,
        isLoading: false
    });

    const navigate = useNavigate();

    const getArticles = () => {
        const token = localStorage.getItem('token');

        if (!token) navigate('/login');

        try {
            setState(prevState => ({...prevState, isLoading: true}));
            const response = get(API_BASE_URL + "/articles", token);
            response.then(data => setState({articles: data.data, isLoading: false}));
        } catch (e) {
            setState(prevState => ({...prevState, isLoading: false}));
            console.error(e);
        }
    }

    useEffect(() => {
        const token = localStorage.getItem('token');

        if (!token) navigate('/login');
        if (!state.articles) getArticles();
    }, []);

    return (
        <div>
            <Header as="h1">Articles</Header>
            {state.isLoading && <Message info header="Loading articles..." />}
            {state.articles && <ArticlesPageTable articles={state.articles} />}
        </div>
    );
};

export default ArticlesPage;

